@@ -29,11 +29,6 @@ method! class_of_operation op =
   | Ispecific _ -> Op_pure
   | _ -> super#class_of_operation op
 
-method! is_cheap_operation op =
-  match op with
-  | Iconst_int n -> n <= 255n && n >= 0n
-  | _ -> false
-
 end
 
 let fundecl f =
