@@ -15,11 +15,16 @@ module Y = struct
     | A : 'a * 'b * ('b -> unit) -> t
 end;; (* should fail *)
 [%%expect{|
-Line 2, characters 2-54:
+Lines 2-3, characters 2-37:
 2 | ..type t = X.t =
 3 |     | A : 'a * 'b * ('b -> unit) -> t
 Error: This variant or record definition does not match that of type X.t
-       The types for field A are not equal.
+       Constructors do not match:
+         A : 'a * 'b * ('a -> unit) -> X.t
+       is not the same as:
+         A : 'a * 'b * ('b -> unit) -> X.t
+       The type 'a -> unit is not equal to the type 'b -> unit
+       Type 'a is not equal to type 'b
 |}]
 
 (* would segfault
