@@ -1,3 +1,10 @@
+(* TEST
+flags = " -w -a "
+* setup-ocamlc.byte-build-env
+** ocamlc.byte
+*** check-ocamlc.byte-output
+*)
+
 module type PR6513 = sig
 module type S = sig type u end
 
