@@ -1,5 +1,5 @@
 (* TEST
-flags = " -w a "
+flags = " -w -a "
 ocamlc_byte_exit_status = "2"
 * setup-ocamlc.byte-build-env
 ** ocamlc.byte
